@@ -20,7 +20,7 @@ Fey::Role::Groupable - A role for things that can be part of a GROUP BY clause
 
 =head1 SYNOPSIS
 
-  use MooseX::StrictConstructor;
+  use Moose;
 
   with 'Fey::Role::Groupable';
 
